@@ -66,6 +66,7 @@ class TestBgpDrAgent(base.BaseTestCase):
         super(TestBgpDrAgent, self).setUp()
         cfg.CONF.register_opts(bgp_config.BGP_DRIVER_OPTS, 'BGP')
         cfg.CONF.register_opts(bgp_config.BGP_PROTO_CONFIG_OPTS, 'BGP')
+        cfg.CONF.register_opts(config.AGENT_STATE_OPTS, 'AGENT')
         mock_log_p = mock.patch.object(bgp_dragent, 'LOG')
         self.mock_log = mock_log_p.start()
         self.driver_cls_p = mock.patch(
@@ -74,17 +75,20 @@ class TestBgpDrAgent(base.BaseTestCase):
         self.driver_cls = self.driver_cls_p.start()
         self.context = context.get_admin_context()
 
-    def test_bgp_dragent_manager(self):
+    @mock.patch('neutron.common.config.init')
+    def test_bgp_dragent_manager(self, mock_init):
+        mock_init.return_value = '/tmp/test'
         state_rpc_str = 'neutron.agent.rpc.PluginReportStateAPI'
         # sync_state is needed for this test
         with mock.patch.object(bgp_dragent.BgpDrAgentWithStateReport,
                                'sync_state',
                                autospec=True) as mock_sync_state:
             with mock.patch(state_rpc_str) as state_rpc:
-                with mock.patch.object(sys, 'argv') as sys_argv:
-                    sys_argv.return_value = [
-                        'bgp_dragent', '--config-file',
-                        base.etcdir('neutron.conf')]
+                test_args = [
+                    'bgp_dragent', '--config-file',
+                    base.etcdir('neutron.conf')
+                ]
+                with mock.patch.object(sys, 'argv', test_args):
                     config.register_agent_state_opts_helper(cfg.CONF)
                     n_config.init(sys.argv[1:])
                     agent_mgr = bgp_dragent.BgpDrAgentWithStateReport(
@@ -109,6 +113,14 @@ class TestBgpDrAgent(base.BaseTestCase):
             bgp_dr.after_start()
             self.assertIsNotNone(len(sync_state.mock_calls))
 
+    def test_agent_updated(self):
+        bgp_dr = bgp_dragent.BgpDrAgentWithStateReport(HOSTNAME)
+        payload = {'admin_state_up': True}
+        with mock.patch.object(bgp_dr, 'agent_updated') as agent_updated:
+            bgp_dr.agent_updated(self.context, payload)
+            self.assertIsNotNone(len(agent_updated.mock_calls))
+            self.assertEqual(1, bgp_dr.agent_updated.call_count)
+
     def _test_sync_state_helper(self, bgp_speaker_list=None,
                                 cached_info=None,
                                 safe_configure_call_count=0,
